# -*- coding: utf-8 -*-

from .callbacks_mixin import AppCallBacksMixin
from .connection import Connection


class Kola(AppCallBacksMixin):
    """
    tcp server
    """

    debug = False
    blueprints = None
    got_first_request = False

    def __init__(self):
        AppCallBacksMixin.__init__(self)
        self.blueprints = dict()

    def register_blueprint(self, blueprint):
        blueprint.register2app(self)
